"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const generator_1 = __importDefault(require("@babel/generator"));
const parser_1 = require("@babel/parser");
const core_1 = require("@babel/core");
const flipper_env_1 = __importDefault(require("./flipper-env"));
function transform({ filename, options, src, presets, plugins, }) {
    presets = (presets !== null && presets !== void 0 ? presets : [require('@babel/preset-react')]);
    plugins = (plugins !== null && plugins !== void 0 ? plugins : []);
    const isTypeScript = filename.endsWith('.tsx') || filename.endsWith('.ts');
    if (!isTypeScript) {
        plugins.unshift(require('@babel/plugin-transform-modules-commonjs'), require('@babel/plugin-proposal-object-rest-spread'), require('@babel/plugin-proposal-class-properties'), require('@babel/plugin-transform-flow-strip-types'), require('@babel/plugin-proposal-optional-chaining'), require('@babel/plugin-proposal-nullish-coalescing-operator'), require('./dynamic-requires'));
    }
    else {
        plugins.unshift(require('@babel/plugin-transform-typescript'), require('@babel/plugin-proposal-class-properties'), require('@babel/plugin-transform-modules-commonjs'), require('@babel/plugin-proposal-optional-chaining'), require('@babel/plugin-proposal-nullish-coalescing-operator'));
    }
    const ast = parser_1.parse(src, {
        sourceFilename: filename,
        plugins: isTypeScript
            ? [
                'jsx',
                'typescript',
                'classProperties',
                'optionalChaining',
                'nullishCoalescingOperator',
            ]
            : [
                'jsx',
                ['flow', { all: true }],
                'classProperties',
                'objectRestSpread',
                'optionalChaining',
                'nullishCoalescingOperator',
            ],
        sourceType: 'module',
    });
    const transformed = core_1.transformFromAstSync(ast, src, {
        ast: true,
        babelrc: !filename.includes('node_modules'),
        code: false,
        comments: false,
        compact: false,
        root: options.projectRoot,
        filename,
        plugins,
        presets,
        sourceMaps: true,
        retainLines: !!flipper_env_1.default.FLIPPER_TEST_RUNNER,
    });
    if (!transformed) {
        throw new Error('Failed to transform');
    }
    const result = generator_1.default(transformed.ast, {
        filename,
        sourceFileName: filename,
        sourceMaps: true,
        retainLines: !!flipper_env_1.default.FLIPPER_TEST_RUNNER,
    }, src);
    return {
        ast: transformed.ast,
        code: result.code,
        filename,
        map: result.map,
    };
}
exports.default = transform;
//# sourceMappingURL=transform.js.map